@@ -71,6 +71,7 @@
     function modal(params) {
       if (params && params.title && params.body) {
         var options = {
+          backdrop: 'static',
           controller: 'SimpleModalController as modalCtrl',
           templateUrl: path + 'modal/simple-modal.html',
           resolve: {
@@ -80,7 +81,7 @@
                 body: params.body,
                 submit: params.submit || gettext('Submit'),
                 cancel: params.cancel || gettext('Cancel'),
-                confirmCssClass: params.confirmCssClass || "btn-primary"
+                confirmCssClass: params.confirmCssClass || "btn-danger"
               };
             }
           }
