@@ -37,11 +37,13 @@ MICROVERSION_FEATURES = {
         "auto_allocated_network": ["2.37", "2.60"],
         "key_types": ["2.2", "2.9"],
         "key_type_list": ["2.9"],
+        "rescue_instance_volume_based": ["2.87", "2.93"],
     },
     "cinder": {
         "groups": ["3.27", "3.43", "3.48", "3.58"],
         "message_list": ["3.5", "3.29"],
         "limits_project_id_query": ["3.43", "3.50", "3.55"],
+        "extend_in_use_volume": ["3.42", "3.60"],
     }
 }
 
