@@ -14,11 +14,11 @@
 #    under the License.
 
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from openstack_dashboard.contrib.developer.profiler import views
 
 
 urlpatterns = [
-    url(r'^$', views.IndexView.as_view(), name='index'),
+    re_path(r'^$', views.IndexView.as_view(), name='index'),
 ]
