@@ -251,9 +251,14 @@ LAUNCH_INSTANCE_DEFAULTS = {
     'disable_volume': False,
     'disable_volume_snapshot': False,
     'enable_scheduler_hints': True,
+    'enable_metadata': True,
+    'enable_net_ports': True,
     'default_availability_zone': 'Any',
 }
 
+# A Django template astring that will be used as default user_data for new VMs
+OPENSTACK_SERVER_DEFAULT_USER_DATA = ""
+
 # The absolute path to the directory where message files are collected.
 # The message file must have a .json file extension. When the user logins to
 # horizon, the message files collected are processed and displayed to the user.
@@ -348,6 +353,10 @@ OPENSTACK_ENDPOINT_TYPE = 'publicURL'
 # external to the OpenStack environment. The default is None. This
 # value should differ from OPENSTACK_ENDPOINT_TYPE if used.
 SECONDARY_ENDPOINT_TYPE = None
+# OPENSTACK_KEYSTONE_ENDPOINT_TYPE specifies the endpoint type use from
+# service catalog when looking up the Keystone (identity) endpoint. This
+# parameter overrides OPENSTACK_ENDPOINT_TYPE.
+OPENSTACK_KEYSTONE_ENDPOINT_TYPE = None
 
 # Set True to disable SSL certificate checks
 # (useful for self-signed certificates):
